SecureMessage

Struct SecureMessage 

pub struct SecureMessage {
    pub type: MessageType,
    pub payload: String,
}
An encrypted message model defines a secure message that has been encrypted using the Sirius’s SDK libraries.

Please note: The strategy to encrypt and decrypt should be consistent between the different SDKs. A client may send a transaction using a different encryption strategy than the recipient. Even though the same encryption algorithm is used, the outcome may still be different depending on the encoding process.

The encryption strategy this SDK uses is UTF-8 and hex encodings: “plain text” string -> utf8 byte array -> encrypted byte array -> hex string

Fields

type: MessageType

Message type

payload: String

Message payload.

Implementations

Source

impl SecureMessage

pub fn create( sender_account: &Account, recipient_public_account: &PublicAccount, payload: &str, ) -> Result<Self>

Creates an encrypted message from [plainTextMessage].

The message is encrypted using a shared key generated by the [senderPrivateKey] and the [recipient_public_key]. The recipient can decrypt this message using this shared key by taking the sender’s public key and the recipient’s public key.

pub fn from_hex_payload(payload: &str) -> Result<Self>

It creates a SecureMessage from the payload hex without the 01 prefix. The 01 prefix will be attached to the final payload.

pub fn from_bytes(bytes: &[u8]) -> Result<Self>

It creates a SecureMessage from the given bytes.

pub fn decrypt( &self, recipient_account: &Account, sender_public_account: PublicAccount, ) -> Result<PlainMessage>

Decrypts an SecureMessage.

Returns a PlainMessage.